@@ -22,6 +22,7 @@ package org.apache.mina.core.filterchain;
 import org.apache.mina.core.session.IdleStatus;
 import org.apache.mina.core.session.IoSession;
 import org.apache.mina.core.write.WriteRequest;
+import org.apache.mina.filter.FilterEvent;
 
 /**
  * An adapter class for {@link IoFilter}.  You can extend
@@ -153,6 +154,14 @@ public class IoFilterAdapter implements IoFilter {
         nextFilter.inputClosed(session);
     }
 
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public void event(NextFilter nextFilter, IoSession session, FilterEvent event) throws Exception {
+        nextFilter.event(session, event);
+    }
+
     /**
      * {@inheritDoc}
      */
