@@ -910,7 +910,9 @@ public abstract class AbstractPollingIoProcessor<S extends AbstractIoSession> im
                 }
 
                 // Reset the Schedule for flush flag for this session,
-                // as we are flushing it now
+                // as we are flushing it now.  This allows another thread
+                // to enqueue data to be written without corrupting the
+                // selector interest state.
                 session.unscheduledForFlush();
 
                 SessionState state = getState(session);
@@ -1106,8 +1108,6 @@ public abstract class AbstractPollingIoProcessor<S extends AbstractIoSession> im
                 try {
                     localWrittenBytes = write(session, buf, length);
                 } catch (IOException ioe) {
-                    ioe.printStackTrace();
-
                     // We have had an issue while trying to send data to the
                     // peer : let's close the session.
                     buf.free();
@@ -1119,27 +1119,9 @@ public abstract class AbstractPollingIoProcessor<S extends AbstractIoSession> im
 
                 session.increaseWrittenBytes(localWrittenBytes, currentTime);
 
-                // Now, forward the original message
+                // Now, forward the original message if it has been fully sent
                 if (!buf.hasRemaining() || (!hasFragmentation && (localWrittenBytes != 0))) {
-                    WriteRequest originalRequest = req.getOriginalRequest();
-
-                    if (originalRequest != null) {
-                        Object originalMessage = originalRequest.getMessage();
-
-                        if (originalMessage instanceof IoBuffer) {
-                            buf = (IoBuffer) originalMessage;
-
-                            int pos = buf.position();
-                            buf.reset();
-                            this.fireMessageSent(session, req);
-                            // And set it back to its position
-                            buf.position(pos);
-                        } else {
-                            this.fireMessageSent(session, req);
-                        }
-                    } else {
-                        this.fireMessageSent(session, req);
-                    }
+                    this.fireMessageSent(session, req);
                 }
             } else {
                 this.fireMessageSent(session, req);
@@ -1159,7 +1141,6 @@ public abstract class AbstractPollingIoProcessor<S extends AbstractIoSession> im
                 filterChain.fireExceptionCaught(e);
             } finally {
                 try {
-                    clearWriteRequestQueue(session);
                     ((AbstractIoService) session.getService()).getListeners().fireSessionDestroyed(session);
                 } catch (Exception e) {
                     // The session was either destroyed or not at this point.
@@ -1168,6 +1149,8 @@ public abstract class AbstractPollingIoProcessor<S extends AbstractIoSession> im
                     // the return value by bubbling up.
                     IoFilterChain filterChain = session.getFilterChain();
                     filterChain.fireExceptionCaught(e);
+                } finally {
+                    clearWriteRequestQueue(session);
                 }
             }
 
@@ -1189,7 +1172,6 @@ public abstract class AbstractPollingIoProcessor<S extends AbstractIoSession> im
                     // The first unwritten empty buffer must be
                     // forwarded to the filter chain.
                     if (buf.hasRemaining()) {
-                        buf.reset();
                         failedRequests.add(req);
                     } else {
                         IoFilterChain filterChain = session.getFilterChain();
